aboutsummaryrefslogtreecommitdiff
path: root/gdb/coffread.c
diff options
context:
space:
mode:
authorJim Kingdon <jkingdon@engr.sgi.com>1993-09-14 18:10:42 +0000
committerJim Kingdon <jkingdon@engr.sgi.com>1993-09-14 18:10:42 +0000
commitfc77365385a7f284e7ce45dac924bbd07d7bc2fb (patch)
tree57d1c24518d8dce2b74a5039457149a16fa9525f /gdb/coffread.c
parent4f0bccc7d88f5d63a2a295d608a17288e138ad44 (diff)
downloadfsf-binutils-gdb-fc77365385a7f284e7ce45dac924bbd07d7bc2fb.zip
fsf-binutils-gdb-fc77365385a7f284e7ce45dac924bbd07d7bc2fb.tar.gz
fsf-binutils-gdb-fc77365385a7f284e7ce45dac924bbd07d7bc2fb.tar.bz2
* paread.c, coffread.c, elfread.c: Include <time.h> before libbfd.h.
Diffstat (limited to 'gdb/coffread.c')
-rw-r--r--gdb/coffread.c10
1 files changed, 8 insertions, 2 deletions
diff --git a/gdb/coffread.c b/gdb/coffread.c
index 7668682..05e9a08 100644
--- a/gdb/coffread.c
+++ b/gdb/coffread.c
@@ -32,6 +32,7 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */
#include <string.h>
+#include <time.h> /* For time_t in libbfd.h. */
#include "libbfd.h" /* FIXME secret internal data from BFD */
#include "coff/internal.h" /* Internal format of COFF symbols in BFD */
#include "libcoff.h" /* FIXME secret internal data from BFD */
@@ -316,7 +317,7 @@ coff_alloc_type (index)
return type;
}
/* Manage the vector of line numbers. */
static void
coff_record_line (line, pc)
@@ -406,6 +407,11 @@ coff_end_symtab (objfile)
last_source_start_addr = cur_src_start_addr;
+ /* For no good reason, this file stores the number of entries in a
+ separate variable instead of in line_vector->nitems. Fix it. */
+ if (line_vector)
+ line_vector->nitems = line_vector_index;
+
/* For COFF, we only have one subfile, so we can just look at
subfiles and not worry about there being other elements in the
chain. We fill in various fields now because we didn't know them
@@ -1951,7 +1957,7 @@ coff_read_enum_type (index, length, lastsym)
/* Fake up support for relocating symbol addresses. FIXME. */
-struct section_offsets coff_symfile_faker = {0};
+struct section_offsets coff_symfile_faker = {{0}};
struct section_offsets *
coff_symfile_offsets (objfile, addr)
@@ -316,7 +317,7 @@ coff_alloc_type (index)
return type;
}
-/* Manage the vector of line numbers. */
+/* Manage the vector of line numbers. FIXME: Use record_line instead. */
static void
coff_record_line (line, pc)